#ifndef H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649
#define H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649

namespace procman
{
  void build_sysinfo_ui();
}

#endif /* H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649 */
